SearchTree

Struct SearchTree 

pub struct SearchTree { /* private fields */ }
A tree that associates a string key with an usize index.

Implementations

Source

impl SearchTree

pub fn get(&self, index: char) -> Option<&Self>

Get an immediate child node associated with the provided character.

pub fn push(&mut self, key: &str, index: usize)

Add a key to the tree

pub fn for_each<E>( &self, f: impl FnMut(usize) -> Result<(), E>, ) -> Result<(), E>

Calls a function on all the keys reachable from this tree node.

Errors

The function doesn’t fail itself, but it does propagate errors from the callback